@@ -7,20 +7,33 @@
 #
 # @author Davide Brunato <brunato@sissa.it>
 #
+from collections import namedtuple
 from collections.abc import MutableMapping, MutableSequence
 from typing import TYPE_CHECKING, cast, Any, Dict, Iterator, Iterable, \
     List, Optional, Type, Tuple, Union
+from xml.etree.ElementTree import Element
 
 from ..exceptions import XMLSchemaTypeError
 from ..names import XSI_NAMESPACE
-from ..etree import etree_element, ElementData
-from ..aliases import NamespacesType, ElementType, BaseXsdType
+from ..aliases import NamespacesType, BaseXsdType
 from ..namespaces import NamespaceMapper
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from ..validators import XsdElement
 
 
+ElementData = namedtuple('ElementData', ['tag', 'text', 'content', 'attributes'])
+"""
+Namedtuple for Element data interchange between decoders and converters.
+The field *tag* is a string containing the Element's tag, *text* can be `None`
+or a string representing the Element's text, *content* can be `None`, a list
+containing the Element's children or a dictionary containing element name to
+list of element contents for the Element's children (used for unordered input
+data), *attributes* can be `None` or a dictionary containing the Element's
+attributes.
+"""
+
+
 class XMLSchemaConverter(NamespaceMapper):
     """
     Generic XML Schema based converter class. A converter is used to compose
@@ -71,8 +84,7 @@ class XMLSchemaConverter(NamespaceMapper):
     dict: Type[Dict[str, Any]] = dict
     list: Type[List[Any]] = list
 
-    etree_element_class: Type[ElementType]
-    etree_element_class = etree_element
+    etree_element_class: Type[Element] = Element
 
     __slots__ = ('text_key', 'ns_prefix', 'attr_prefix', 'cdata_prefix',
                  'indent', 'preserve_root', 'force_dict', 'force_list')
@@ -80,7 +92,7 @@ class XMLSchemaConverter(NamespaceMapper):
     def __init__(self, namespaces: Optional[NamespacesType] = None,
                  dict_class: Optional[Type[Dict[str, Any]]] = None,
                  list_class: Optional[Type[List[Any]]] = None,
-                 etree_element_class: Optional[Type[ElementType]] = None,
+                 etree_element_class: Optional[Type[Element]] = None,
                  text_key: Optional[str] = '$',
                  attr_prefix: Optional[str] = '@',
                  cdata_prefix: Optional[str] = None,
@@ -181,12 +193,9 @@ class XMLSchemaConverter(NamespaceMapper):
         """
         if self.attr_prefix is None or not attributes:
             return
-        elif self.attr_prefix:
-            for name, value in attributes:
-                yield '%s%s' % (self.attr_prefix, self.map_qname(name)), value
         else:
             for name, value in attributes:
-                yield self.map_qname(name), value
+                yield self.attr_prefix + self.map_qname(name), value
 
     def map_content(self, content: Iterable[Tuple[str, Any, Any]]) \
             -> Iterator[Tuple[str, Any, Any]]:
@@ -209,13 +218,13 @@ class XMLSchemaConverter(NamespaceMapper):
                     yield name, value, xsd_child
             except TypeError:
                 if self.cdata_prefix is not None:
-                    yield '%s%s' % (self.cdata_prefix, name), value, xsd_child
+                    yield f'{self.cdata_prefix}{name}', value, xsd_child
 
     def etree_element(self, tag: str,
                       text: Optional[str] = None,
-                      children: Optional[List[ElementType]] = None,
+                      children: Optional[List[Element]] = None,
                       attrib: Optional[Dict[str, str]] = None,
-                      level: int = 0) -> ElementType:
+                      level: int = 0) -> Element:
         """
         Builds an ElementTree's Element using arguments and the element class and
         the indent spacing stored in the converter instance.
@@ -227,7 +236,7 @@ class XMLSchemaConverter(NamespaceMapper):
         :param level: the level related to the encoding process (0 means the root).
         :return: an instance of the Element class is set for the converter instance.
         """
-        if type(self.etree_element_class) is type(etree_element):
+        if type(self.etree_element_class) is type(Element):
             if attrib is None:
                 elem = self.etree_element_class(tag)
             else:
@@ -255,7 +264,7 @@ class XMLSchemaConverter(NamespaceMapper):
         Converts a decoded element data to a data structure.
 
         :param data: ElementData instance decoded from an Element node.
-        :param xsd_element: the `XsdElement` associated to decoded the data.
+        :param xsd_element: the `XsdElement` associated to decode the data.
         :param xsd_type: optional XSD type for supporting dynamic type through \
         *xsi:type* or xs:alternative.
         :param level: the level related to the decoding process (0 means the root).
@@ -266,7 +275,7 @@ class XMLSchemaConverter(NamespaceMapper):
         if level == 0 and xsd_element.is_global() and not self.strip_namespaces and self:
             schema_namespaces = set(xsd_element.namespaces.values())
             result_dict.update(
-                ('%s:%s' % (self.ns_prefix, k) if k else self.ns_prefix, v)
+                (f'{self.ns_prefix}:{k}' if k else self.ns_prefix, v)
                 for k, v in self._namespaces.items()
                 if v in schema_namespaces or v == XSI_NAMESPACE
             )
@@ -274,15 +283,15 @@ class XMLSchemaConverter(NamespaceMapper):
         xsd_group = xsd_type.model_group
         if xsd_group is None:
             if data.attributes or self.force_dict and not xsd_type.is_simple():
-                result_dict.update(t for t in self.map_attributes(data.attributes))
-                if data.text is not None and data.text != '' and self.text_key is not None:
+                result_dict.update(self.map_attributes(data.attributes))
+                if data.text is not None and self.text_key is not None:
                     result_dict[self.text_key] = data.text
                 return result_dict
             else:
-                return data.text if data.text != '' else None
+                return data.text
         else:
             if data.attributes:
-                result_dict.update(t for t in self.map_attributes(data.attributes))
+                result_dict.update(self.map_attributes(data.attributes))
 
             has_single_group = xsd_group.is_single()
             if data.content:
@@ -303,7 +312,7 @@ class XMLSchemaConverter(NamespaceMapper):
                         else:
                             result_dict[name] = self.list([result, value])
 
-            elif data.text is not None and data.text != '' and self.text_key is not None:
+            elif data.text is not None and self.text_key is not None:
                 result_dict[self.text_key] = data.text
 
             if level == 0 and self.preserve_root:
@@ -361,7 +370,7 @@ class XMLSchemaConverter(NamespaceMapper):
                 content.append((index, value))
             elif name == self.ns_prefix:
                 self[''] = value
-            elif name.startswith('%s:' % self.ns_prefix):
+            elif name.startswith(f'{self.ns_prefix}:'):
                 if not self.strip_namespaces:
                     self[name[len(self.ns_prefix) + 1:]] = value
             elif self.attr_prefix and \
