@@ -8,14 +8,14 @@
 # @author Davide Brunato <brunato@sissa.it>
 #
 from typing import TYPE_CHECKING, Any, Optional, cast, Iterable, Union, Callable
+from elementpath.etree import etree_tostring
 
 from ..exceptions import XMLSchemaException, XMLSchemaWarning, XMLSchemaValueError
-from ..etree import etree_tostring
 from ..aliases import ElementType, NamespacesType, SchemaElementType, ModelParticleType
 from ..helpers import get_prefixed_qname, etree_getpath, is_etree_element
 from ..translation import gettext as _
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from ..resources import XMLResource
     from .xsdbase import XsdValidator
     from .groups import XsdGroup
@@ -240,7 +240,7 @@ class XMLSchemaValidationError(XMLSchemaValidatorError, ValueError):
             msg.append('Reason: %s\n' % self.reason)
 
         if hasattr(self.validator, 'tostring'):
-            chunk = self.validator.tostring('  ', 20)  # type: ignore[union-attr]
+            chunk = self.validator.tostring('  ', 20)
             msg.append("Schema:\n\n%s\n" % chunk)
 
         if self.elem is not None and is_etree_element(self.elem):
