@@ -16,22 +16,23 @@ import operator
 from abc import abstractmethod
 from typing import TYPE_CHECKING, cast, Any, List, Optional, Pattern, Union, \
     MutableSequence, overload, Tuple
+from xml.etree.ElementTree import Element
+
 from elementpath import XPath2Parser, XPathContext, ElementPathError, \
-    translate_pattern, RegexError
+    translate_pattern, RegexError, ElementNode
 
 from ..names import XSD_LENGTH, XSD_MIN_LENGTH, XSD_MAX_LENGTH, XSD_ENUMERATION, \
     XSD_INTEGER, XSD_WHITE_SPACE, XSD_PATTERN, XSD_MAX_INCLUSIVE, XSD_MAX_EXCLUSIVE, \
     XSD_MIN_INCLUSIVE, XSD_MIN_EXCLUSIVE, XSD_TOTAL_DIGITS, XSD_FRACTION_DIGITS, \
     XSD_ASSERTION, XSD_DECIMAL, XSD_EXPLICIT_TIMEZONE, XSD_NOTATION_TYPE, XSD_QNAME, \
     XSD_ANNOTATION
-from ..etree import etree_element
 from ..aliases import ElementType, SchemaType, AtomicValueType, BaseXsdType
 from ..translation import gettext as _
 from ..helpers import count_digits, local_name
 from .exceptions import XMLSchemaValidationError, XMLSchemaDecodeError
 from .xsdbase import XsdComponent, XsdAnnotation
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from .simple_types import XsdList, XsdAtomicRestriction
 
 LaxDecodeType = Tuple[Any, List[XMLSchemaValidationError]]
@@ -753,14 +754,16 @@ XsdAssertionXPathParser.unregister('position')
 
 
 # noinspection PyUnusedLocal
-@XsdAssertionXPathParser.method(XsdAssertionXPathParser.function('last', nargs=0))
-def evaluate_last(self, context=None):  # type: ignore[no-untyped-def]
+@XsdAssertionXPathParser.method(  # type: ignore[no-untyped-def]
+    XsdAssertionXPathParser.function('last', nargs=0))
+def evaluate_last(self, context=None):
     raise self.missing_context("context item size is undefined")
 
 
 # noinspection PyUnusedLocal
-@XsdAssertionXPathParser.method(XsdAssertionXPathParser.function('position', nargs=0))
-def evaluate_position(self, context=None):  # type: ignore[no-untyped-def]
+@XsdAssertionXPathParser.method(  # type: ignore[no-untyped-def]
+    XsdAssertionXPathParser.function('position', nargs=0))
+def evaluate_position(self, context=None):
     raise self.missing_context("context item position is undefined")
 
 
@@ -777,7 +780,7 @@ class XsdAssertionFacet(XsdFacet):
         </assertion>
     """
     _ADMITTED_TAGS = {XSD_ASSERTION}
-    _root = etree_element('root')
+    _root = ElementNode(elem=Element('root'))
 
     def __repr__(self) -> str:
         return '%s(test=%r)' % (self.__class__.__name__, self.path)
